<h3 align="center">
	<img src="https://github.com/diesphink/meni/assets/10153740/de6a22f8-3887-43cc-a98e-797afca7ae84" width="150" alt="Logo"/><br/>
	Meni
</h3>

<h6 align="center">
  <a href="#">Downloads</a>
  ·
  <a href="#">Features</a>
  ·
  <a href="#">Screenshots</a>
  ·
  <a href="#">Installation</a>
  ·
  <a href="#">Docs</a>
</h6>

<p align="center">
  <a href="https://github.com/diesphink/meni/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/badge/version-0.1.0-blue.svg" target="_blank" /></a>
  <a href="https://github.com/diesphink/meni/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/badge/license-BSD-darkcyan.svg" target="_blank" /></a>
</p>

<p align="center">
Meni 3D Library is a tool designed to streamline the management of your 3D model (STL) library, offering a smoother experience for 3D printer owners.
<br>
Developed in Python using <a href="https://doc.qt.io/qtforpython-6/index.html">Qt (PySide6)</a>, with model loading facilitated by <a href="https://github.com/WoLpH/numpy-stl/">numpy-stl</a> and visualization handled by <a href="https://github.com/bwoodsend/vtkplotlib">vtkplotlib</a>.
</p>

## Features

- Enjoy the speed, reliability, and convenience of a local (desktop) application.
- Easily import files into your library for effortless retrieval, without concerns about file names or folder structure.
- Organize your files into collections for seamless grouping when necessary.
- Quickly preview and manipulate models upon selection.
- Enhance organization with a tag system.

## Screenshots

![image](https://github.com/diesphink/meni/assets/10153740/73e69b09-3379-403d-b712-0054c161161b)




## Installation

TODO: Guide on installation

## Author

👤 **Diego Pereyra**

- Twitter: [@sphink](https://twitter.com/sphink)
- Github: [@diesphink](https://github.com/diesphink)

## License

Copyright © 2024 [Diego Pereyra](https://github.com/diesphink).<br />
This project is [BSD](https://github.com/diesphink/meni/blob/master/LICENSE) licensed.
